==> 0.0.13.tar.gz: lib/antsomi_method_channel.dart <==
import 'dart:async';

import 'package:antsomisdk/catalog.dart';
import 'package:antsomisdk/cdp_event.dart';
import 'package:antsomisdk/inbox_items.dart';
import 'package:antsomisdk/screen_observer.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'dart:convert';

import 'antsomi_platform_interface.dart';
import 'modify_action.dart';

/// An implementation of [AntsomiPlatform] that uses method channels.
class MethodChannelAntsomi extends AntsomiPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('antsomi');

  MethodChannelAntsomi() {
    methodChannel.setMethodCallHandler(_methodHandler);
  }

  Future<void> _methodHandler(MethodCall call) async {
    switch (call.method) {
      case "onReceiveNewData":
        final String? objNewData = call.arguments;
        final InboxItem newData = InboxItem.fromRawJson(objNewData ?? "");
        callback(newData);
        break;
      case "setAction":
        setDefaultAction!();
      case "handleDeepLink":
        final String url = call.arguments;
        deepLinkHandler(url);
      default:
        debugPrint("No method handler for ${call.method}");
    }
  }

  @override
  void track({required CDPEvent event}) async {
    final eventDecoded = _decodeCDPEvent(event);

    await methodChannel.invokeMethod('track', {'event': eventDecoded});
  }

  @override
  void parseDeepLink(Uri url) async {
    final urlString = url.toString();
    await methodChannel.invokeMethod('parseDeepLink', {'url': urlString});
  }

  Map<String, String> decodeObject(Object? data) {
    Map<String, String> decoder =
        Map<String, String>.from(data as Map<Object?, Object?>);
    return decoder;
  }

  @override
  Future<String?> getPlatformVersion() async {
    final version =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> getCustomerId() async {
    final id = await methodChannel.invokeMethod<String>('getCustomerId');
    return id;
  }

  @override
  Future<String?> getPortalId() async {
    final id = await methodChannel.invokeMethod<String>('getPortalId');
    return id;
  }

  @override
  Future<String?> getPropsId() async {
    final id = await methodChannel.invokeMethod<String>('getPropsId');
    return id;
  }

  @override
  Future<String?> getDeviceId() async {
    final id = await methodChannel.invokeMethod<String>('getDeviceId');
    return id;
  }

  @override
  Future setCustomerProperties(
      {required String customerId,
      Map<String, String>? customerProperties = const {}}) async {
    await methodChannel.invokeMethod("setCustomerProperties",
        {"customerId": customerId, "customerProperties": customerProperties});
  }

  @override
  Future<Map<String, String>> getMessageById(
      {required String messageId}) async {
    final result = await methodChannel
        .invokeMethod("getMessageById", {"messageId": messageId});
    final Map<String, String> decoded =
        Map<String, String>.from(result as Map<Object?, Object?>);
    return decoded;
  }

  @override
  Future<String?> getContext() async {
    final result = await methodChannel.invokeMethod<String>('getContext');
    return result;
  }

  @override
  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) async {
    final result = await methodChannel.invokeMethod("config", {
      "portalId": portalId,
      "propsId": propsId,
      "appGroupId": appGroupId,
      "applicationId": applicationId
    });
    ScreenObserver().screenStream.listen((name) {
      methodChannel.invokeMethod('trackScreen', {'name': name});
    });
    return result;
  }

  @override
  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    methodChannel.invokeMethod(
        'trackScreen', {'name': name, 'type': type, 'title': title});
  }

  @override
  Future appInboxInit(
      {required String destinationId, required String audienceType}) async {
    await methodChannel.invokeMethod("appInboxInit",
        {"destinationId": destinationId, "audienceType": audienceType});
  }

  @override
  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) async {
    List<InboxItem> decodedResult = [];

    final result = await methodChannel
        .invokeListMethod("getMessage", {"catalogId": catalogId, "page": page});

    if (result != null) {
      for (var element in result) {
        final Map<String, dynamic> decoder = jsonDecode(jsonEncode(element));

        final decoders = InboxItem.fromJson(decoder);
        decodedResult.add(decoders);
      }
    }

    return decodedResult;
  }

  @override
  Future<String?> getUID() async {
    final uid = await methodChannel.invokeMethod<String>("getUID");
    return uid;
  }

  @override
  Future<int?> getUnreadMessageCount() async {
    final count =
        await methodChannel.invokeMethod<int>('getUnreadMessageCount');
    return count;
  }

  Future<Map<String, String>> newMessageReceived() async {
    Map<String, String>? decoder;
    final result =
        await methodChannel.invokeMethod<Object?>("newMessageReceived");
    if (result != null) {
      decoder = Map<String, String>.from(result as Map<Object?, Object?>);
    }
    return decoder!;
  }

  @override
  Future<List<Catalog>> getAllLabels() async {
    final result = await methodChannel.invokeListMethod("getAllLabels");

    List<Catalog> catalog = [];
    if (result != null) {
      for (var item in result) {
        catalog.add(Catalog.fromRawJson(item));
      }
    }
    return catalog;
  }

  @override
  void onNewMessageReceived(
      void Function(InboxItem callbackValue)? callback) async {
    this.callback = callback!;
  }

  @override
  void modifyAction(
      {required String messageId, required ActionType action}) async {
    await methodChannel.invokeMethod(
        "modifyAction", {"messageId": messageId, "action": action.value});
  }

  Map<String, dynamic> _decodeCDPEvent(CDPEvent event) {
    Map<String, dynamic> result;
    result = {
      "en": event.en,
      "items": event.items,
      "userProps": event.userProps,
      "objectProps": event.objectProps,
      "eventProps": event.eventProps,
      "customerProps": event.customerProps,
    };
    return result;
  }

  @override
  void setPageLimit({required int limit}) {
    unawaited(
        methodChannel.invokeMethod<void>("setPageLimit", {"limit": limit}));
  }

  // @override
  // Map<String, dynamic> parseLink(Uri url) {
  //   return url.queryParameters;
  // }
}

==> 0.0.23.tar.gz: lib/antsomi_method_channel.dart <==
import 'dart:async';

import 'package:antsomisdk/catalog.dart';
import 'package:antsomisdk/cdp_event.dart';
import 'package:antsomisdk/inbox_items.dart';
import 'package:antsomisdk/screen_observer.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'dart:convert';

import 'antsomi_platform_interface.dart';
import 'modify_action.dart';

/// An implementation of [AntsomiPlatform] that uses method channels.
class MethodChannelAntsomi extends AntsomiPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('antsomi');

  MethodChannelAntsomi() {
    methodChannel.setMethodCallHandler(_methodHandler);
  }

  Future<void> _methodHandler(MethodCall call) async {
    switch (call.method) {
      case "onReceiveNewData":
        final String? objNewData = call.arguments;
        final InboxItem newData = InboxItem.fromRawJson(objNewData ?? "");
        callback(newData);
        break;
      case "setAction":
        setDefaultAction!();
      case "handleDeepLink":
        final String url = call.arguments;
        deepLinkHandler(url);
      default:
        debugPrint("No method handler for ${call.method}");
    }
  }

  @override
  void track({required CDPEvent event}) async {
    final eventDecoded = _decodeCDPEvent(event);

    await methodChannel.invokeMethod('track', {'event': eventDecoded});
  }

  @override
  void parseDeepLink(Uri url) async {
    final urlString = url.toString();
    await methodChannel.invokeMethod('parseDeepLink', {'url': urlString});
  }

  Map<String, String> decodeObject(Object? data) {
    Map<String, String> decoder =
        Map<String, String>.from(data as Map<Object?, Object?>);
    return decoder;
  }

  @override
  Future<String?> getPlatformVersion() async {
    final version =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> getCustomerId() async {
    final id = await methodChannel.invokeMethod<String>('getCustomerId');
    return id;
  }

  @override
  Future<String?> getPortalId() async {
    final id = await methodChannel.invokeMethod<String>('getPortalId');
    return id;
  }

  @override
  Future<String?> getPropsId() async {
    final id = await methodChannel.invokeMethod<String>('getPropsId');
    return id;
  }

  @override
  Future<String?> getDeviceId() async {
    final id = await methodChannel.invokeMethod<String>('getDeviceId');
    return id;
  }

  @override
  Future setCustomerProperties(
      {required String customerId,
      Map<String, String>? customerProperties = const {}}) async {
    await methodChannel.invokeMethod("setCustomerProperties",
        {"customerId": customerId, "customerProperties": customerProperties});
  }

  @override
  Future<Map<String, String>> getMessageById(
      {required String messageId}) async {
    final result = await methodChannel
        .invokeMethod("getMessageById", {"messageId": messageId});
    final Map<String, String> decoded =
        Map<String, String>.from(result as Map<Object?, Object?>);
    return decoded;
  }

  @override
  Future<String?> getContext() async {
    final result = await methodChannel.invokeMethod<String>('getContext');
    return result;
  }

  @override
  Future<bool?> config(
      {required String portalId,
      required String propsId,
      required String appGroupId,
      required String applicationId}) async {
    final result = await methodChannel.invokeMethod("config", {
      "portalId": portalId,
      "propsId": propsId,
      "appGroupId": appGroupId,
      "applicationId": applicationId
    });
    ScreenObserver().screenStream.listen((name) {
      methodChannel.invokeMethod('trackScreen', {'name': name});
    });
    return result;
  }

  @override
  void trackScreen(
      {required String name, String title = "", String type = ""}) {
    methodChannel.invokeMethod(
        'trackScreen', {'name': name, 'type': type, 'title': title});
  }

  @override
  Future appInboxInit(
      {required String destinationId, required String audienceType}) async {
    await methodChannel.invokeMethod("appInboxInit",
        {"destinationId": destinationId, "audienceType": audienceType});
  }

  @override
  Future<List<InboxItem>> getMessage(
      {List<String>? catalogId = const [], required int page}) async {
    List<InboxItem> decodedResult = [];

    final result = await methodChannel
        .invokeListMethod("getMessage", {"catalogId": catalogId, "page": page});

    if (result != null) {
      for (var element in result) {
        final Map<String, dynamic> decoder = jsonDecode(jsonEncode(element));

        final decoders = InboxItem.fromJson(decoder);
        decodedResult.add(decoders);
      }
    }

    return decodedResult;
  }

  @override
  Future<String?> getUID() async {
    final uid = await methodChannel.invokeMethod<String>("getUID");
    return uid;
  }

  @override
  Future<int?> getUnreadMessageCount() async {
    final count =
        await methodChannel.invokeMethod<int>('getUnreadMessageCount');
    return count;
  }

  Future<Map<String, String>> newMessageReceived() async {
    Map<String, String>? decoder;
    final result =
        await methodChannel.invokeMethod<Object?>("newMessageReceived");
    if (result != null) {
      decoder = Map<String, String>.from(result as Map<Object?, Object?>);
    }
    return decoder!;
  }

  @override
  Future<List<Catalog>> getAllLabels() async {
    final result = await methodChannel.invokeListMethod("getAllLabels");

    List<Catalog> catalog = [];
    if (result != null) {
      for (var item in result) {
        catalog.add(Catalog.fromRawJson(item));
      }
    }
    return catalog;
  }

  @override
  void onNewMessageReceived(
      void Function(InboxItem callbackValue)? callback) async {
    this.callback = callback!;
  }

  @override
  void modifyAction(
      {required List<String> messageId, required int action}) async {
    await methodChannel.invokeMethod(
        "modifyAction", {"messageId": messageId, "action": action});
  }

  Map<String, dynamic> _decodeCDPEvent(CDPEvent event) {
    Map<String, dynamic> result;
    result = {
      "en": event.en,
      "items": event.items,
      "userProps": event.userProps,
      "objectProps": event.objectProps,
      "eventProps": event.eventProps,
      "customerProps": event.customerProps,
    };
    return result;
  }

  @override
  void setPageLimit({required int limit}) {
    unawaited(
        methodChannel.invokeMethod<void>("setPageLimit", {"limit": limit}));
  }

  // @override
  // Map<String, dynamic> parseLink(Uri url) {
  //   return url.queryParameters;
  // }
}
